/******************************************************************************

  Copyright (c) 2002-2007 by Turku PET Centre

  halflife.h
  
  Reference: Table of Isotopes, Sixth edition, edited by C.M. Lederer,
  J.M. Hollander, I. Perlman. WILEY, 1967.

  Date:
  2002-01-30 Vesa Oikonen
    First created.
  2002-08-08 VO
    Ga68 changed from 67.8 to 68.0 as requested by Tuula Tolvanen.
  2002-08-28 VO
    Included unofficial isotopes Br76, Rb82 and Cu62.
  2003-07-07 VO
    Included function definitions for halflife.c.
  2004-02-02 VO
    Included unofficial half-lives for Br-75, Cu-64, Fe-52, O-14, Na-22 and
    Zn-62.
  2005-01-21 VO
    Included hlCorrectIsotopeCode().
  2007-02-01 VO
    See halflife.c.
  2007-03-30 Kaisa Liukko
    Added isotope I-124
    

******************************************************************************/
#ifndef _HALFLIFE_H
#define _HALFLIFE_H
/*****************************************************************************/
/** Isotope halflife in minutes */
#define HL_O15 2.05 /* 123 s */
#define HL_N13 10.0
#define HL_C11 20.4
#define HL_F18 109.8
#define HL_Ge68 396000.0 /* 275 d */
#define HL_Ga68 68.0
/*****************************************************************************/
/* The following halflifes have not been checked from the reference;         */
/* they are thus meant to be used only during program development period     */
#define HL_Br75 98.0
#define HL_Br76 978.33 /* 58700 s */
#define HL_Cu62 9.7    /* 582 s */
#define HL_Cu64 768.0
#define HL_Fe52 4980.0
#define HL_Na22 1368000.0
#define HL_O14 1.1818
#define HL_Rb82 1.25   /* 75 s */
#define HL_Zn62 558.0
#define HL_I124 6013.44 /* 4.176 */
/*****************************************************************************/
/* Add ln(2) if it is not defined */
#ifndef M_LN2
#define M_LN2       0.69314718055994530942
#endif
/*****************************************************************************/
extern char *hlIsotopeCode(int isotope);
extern double hlFromIsotope(char *isocode);
extern double hl2lambda(double halflife);
extern double hlLambda2factor(double lambda, double frametime, double framedur);
extern float hlLambda2factor_float(float lambda, float frametime, float framedur);
extern char *hlCorrectIsotopeCode(char *isocode);
extern int hlIsotopeFromHalflife(double halflife);
/*****************************************************************************/
/* Deprecated function names. Please don't use these anymore */
#define lambda2factor hlLambda2factor
#define lambda2factor_float hlLambda2factor_float
/*****************************************************************************/
#endif
